@@ -130,7 +130,6 @@ void GetFlags(int nargs,                /* nargs as passed into main */
    *flush = 0;
    *ptrbits = 0;
    *mhz = 0;
-   *mach = 0;
    *vec = 0;
    *asmb = 0;
    *OS = 0;
@@ -162,6 +161,19 @@ void GetFlags(int nargs,                /* nargs as passed into main */
             }
          }
          break;
+      case 'A':
+         if (++i >= nargs)
+            PrintUsage(args[0], i, "out of arguments");
+         if(args[i][0] >= '0' && args[i][0] <= '9') /* giving a # */
+            *mach = atoi(args[i]);
+         else /* giving a architecture name */
+         {
+            for (k=1; k < NMACH; k++)
+               if (!strcmp(args[i], machnam[k]))
+                  break;
+            *mach = (k == NMACH) ? 0 : k;
+         }
+         break;
       case 'f':
          if (++i >= nargs)
             PrintUsage(args[0], i, "out of arguments");
@@ -177,11 +189,6 @@ void GetFlags(int nargs,                /* nargs as passed into main */
             PrintUsage(args[0], i, "out of arguments");
          *mhz = atoi(args[i]);
          break;
-      case 'A':
-         if (++i >= nargs)
-            PrintUsage(args[0], i, "out of arguments");
-         *mach = atoi(args[i]);
-         break;
       case 'V':
          if (++i >= nargs)
             PrintUsage(args[0], i, "out of arguments");
@@ -326,7 +333,10 @@ void GetFlags(int nargs,                /* nargs as passed into main */
          {
             if (++i >= nargs)
                PrintUsage(args[0], i, "out of arguments");
-            *gccflags = args[i];
+            if (args[i-2][1] == 'C')
+               comps[GCC_] = args[i];
+            else
+               *gccflags = args[i];
          }
          else
          {
@@ -395,6 +405,9 @@ char *GetPtrbitsFlag(enum OSTYPE OS, enum MACHTYPE arch, int ptrbits,
       return((ptrbits == 64) ? "-mabi=64" : "-mabi=n32");
    if (MachIsS390(arch))
       return((ptrbits == 64) ? "-m64" : "-m31");
+   if (OS == OSAIX)
+      return((ptrbits == 64) ? "-maix64" : "-maix32");
+
    if (!CompIsGcc(comp))
    {
 /*
@@ -419,11 +432,11 @@ char *GetPtrbitsFlag(enum OSTYPE OS, enum MACHTYPE arch, int ptrbits,
    else if (OS == OSAIX)
       sp = (ptrbits == 64) ? "-maix64" : "-maix32";
    else if ((MachIsX86(arch) || MachIsPPC(arch) || MachIsUS(arch)) ||
-            arch == IbmPwr7 || arch == IbmPwr6)
+            arch == IbmPwr7 || arch == IbmPwr6 || arch == Pwre6500)
    {
       if (ptrbits == 64)
          sp = "-m64";
-       else if (ptrbits == 32)
+      else if (ptrbits == 32)
          sp = "-m32";
    }
    return(sp);
@@ -466,8 +479,10 @@ int main(int nargs, char **args)
 /*
  * Update l2size, and set f2cdefs/cdefs if they are null
  */
-   if (!l2size) l2size = 4*1024*1024;
-   else l2size *= 1024;
+   if (!l2size)
+      l2size = ((ptrbits == 64) ? 32 : 4) * 1024*1024;
+   else
+      l2size *= 1024;
    if (!f2cdefs) f2cdefs = "";
 /*
  * Append any appended flags, and then we have just compilers and flags
@@ -529,7 +544,7 @@ int main(int nargs, char **args)
          ISAX = i;
 
    fprintf(fpout, "#  ----------------------------\n");
-   fprintf(fpout, "#  Make.inc for ATLAS3.10.1\n");
+   fprintf(fpout, "#  Make.inc for ATLAS3.10.3\n");
    fprintf(fpout, "#  ----------------------------\n\n");
 
    fprintf(fpout, "#  ----------------------------------\n");
@@ -542,6 +557,9 @@ int main(int nargs, char **args)
    fprintf(fpout, "#  -------------------------------------------------\n");
    fprintf(fpout, "   ARCH = %s", machnam[mach]);
    fprintf(fpout, "%d", ptrbits);
+   #if defined(__powerpc64__) && defined(__ORDER_LITTLE_ENDIAN__)
+      fprintf(fpout, "LE");
+   #endif
    if (ISAX)
       fprintf(fpout, "%s", ISAXNAM[ISAX]);
    if (!USEIEEE)
@@ -576,6 +594,8 @@ int main(int nargs, char **args)
    fprintf(fpout, "   FLAdir = $(BLDdir)/src/lapack/reference\n");
    if (ADd)
       fprintf(fpout, "   ADdir  = %s\n", ADd);
+   else if (OS == OSWin64 && ptrbits == 64)
+      fprintf(fpout, "   ADdir  = $(SRCdir)/CONFIG/ARCHS/WIN64\n");
    else
       fprintf(fpout, "   ADdir  = $(SRCdir)/CONFIG/ARCHS\n");
    fprintf(fpout, "\n");
@@ -660,7 +680,7 @@ int main(int nargs, char **args)
          fprintf(fpout, " %d", tids[k]);
    }
    else
-      fprintf(fpout, "TIDLIST=");
+      fprintf(fpout, "   TIDLIST=");
    fprintf(fpout, "\n\n");
 
    fprintf(fpout,
@@ -691,6 +711,10 @@ int main(int nargs, char **args)
       fprintf(fpout, " -m32");
    else if (strstr(comps[NCOMP+DKC_], " -m64"))
       fprintf(fpout, " -m64");
+   else if (strstr(comps[NCOMP+DKC_], " -maix64"))
+      fprintf(fpout, " -maix64");
+   else if (strstr(comps[NCOMP+DKC_], " -maix32"))
+      fprintf(fpout, " -maix32");
    if (cdefs) fprintf(fpout, " %s", cdefs);
    if (THREADS)
    {
@@ -739,7 +763,10 @@ int main(int nargs, char **args)
           comps[i][j-2] == 'c' && comps[i][j-1] == 'c')
          break;
    }
-   goodgcc = (i < NCOMP) ? comps[i] : "gcc";
+   if (i < NCOMP)
+      goodgcc = comps[i];
+   else
+      goodgcc = comps[GCC_] ? comps[GCC_] : "gcc";
    fprintf(fpout, "   GOODGCC = %s", goodgcc);
    if (gccflags)
       fprintf(fpout, " %s", gccflags);
@@ -824,8 +851,10 @@ int main(int nargs, char **args)
    fprintf(fpout, "   SSLAPACKlib =  # set to serial system lapack\n");
    if (THREADS)
    {
-      if (OSIsWin(OS))
+      if (USEMINGW || (ptrbits == 32 && OSIsWin(OS)))
          fprintf(fpout, "   LIBS = -lkernel32 -lm\n\n");
+      else if (OSIsWin(OS))
+         fprintf(fpout, "   LIBS = -lm\n\n");
       else
          fprintf(fpout, "   LIBS = -lpthread -lm\n\n");
    }
@@ -860,6 +889,8 @@ int main(int nargs, char **args)
          }
          else sp = NewStringCopy("gcc");
       }
+      else if (CompIsClang(comps[i]))
+         sp = NewStringCopy((i==F77_) ? "gfortran" : "clang");
       else
       {
          sp = NameWithoutPath(comps[i]);
