@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 1998 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -348,21 +348,30 @@ long long GetLastLongWithRound(char *ln)
 {
    int i;
    long iret=0;
-   for (i=0; ln[i]; i++);
-   if (i > 0)
+   double d;
+
+   for (i=0; ln[i]; i++);  /* find end of string */
+   if (!i)                 /* empty string */
+     return(0);            /* returns 0 */
+/*
+ * Now skip any non-digit info at end of string (eg., MHz)
+ */
+   for(i--; i > 0 && !isdigit(ln[i]); i--);
+   if (!isdigit(ln[i])) /* no digits in string */
+      return(0);        /* returns 0 */
+/*
+ * Go backwards until we find a non-digit to possibly end the number
+ */
+   for (i--; i > 0 && isdigit(ln[i]); i--);
+   if (i > 0)  /* may be more to this number */
    {
-      for (i--; i > 0 && !isdigit(ln[i]); i--);
-      if (i > 0 && ln[i] == '.')  /* allow skip of 1 decimal point */
-         for (i--; i > 0 && !isdigit(ln[i]); i--);
-   }
-   if (i > 0 || (i == 0 && (isdigit(ln[0]) || ln[0] == '.')))
-   {
-      double d;
-      while(isdigit(ln[i]) && i > 0) i--;
-      if (!isdigit(ln[i])) i++;
-      sscanf(ln+i, "%lf", &d);
-      iret = (int)(d+0.5);
+      if (ln[i] == '.')
+         for(i--; i > 0 && isdigit(ln[i]); i--);
    }
+   else if (ln[0] != '.' && !isdigit(ln[0]))
+      i = 1;
+   sscanf(ln+i, "%lf", &d);
+   iret = (int)(d+0.5);
    return(iret);
 }
 
@@ -443,7 +452,7 @@ void GetEnter(FILE *fpout)
 {
    char ln[128];
    fprintf(fpout, "---------- PRESS ENTER TO CONTINUE ---------- ");
-   fgets(ln, 128, stdin);
+   assert(fgets(ln, 128, stdin));
 }
 
 int DisplayFile(char *fnam, FILE *fpout, int nlines)
@@ -563,6 +572,7 @@ enum ARCHFAM ProbeArchFam(char *targ)
       else if (strstr(res, "ia64")) fam = AFIA64;
       else if (strstr(res, "mips")) fam = AFMIPS;
       else if (strstr(res, "arm")) fam = AFARM;
+      else if (strstr(res, "aarch64")) fam = AFARM;
       else if (strstr(res, "s390")) fam = AFS390;
       else if ( strstr(res, "i686") || strstr(res, "i586") ||
                 strstr(res, "i486") || strstr(res, "i386") ||
@@ -588,6 +598,7 @@ enum ARCHFAM ProbeArchFam(char *targ)
                    strstr(res, "x86_64") ) fam = AFX86;
          else if (strstr(res, "mips")) fam = AFMIPS;
          else if (strstr(res, "arm")) fam = AFARM;
+         else if (strstr(res, "aarch64")) fam = AFARM;
          else if (strstr(res, "s390")) fam = AFS390;
          free(res);
       }
@@ -729,7 +740,7 @@ int GetIntVers(char *str, int *nskip)
 
 void GetGccVers(char *gcc, int *comp, int *major, int *minor, int *patch)
 /*
- * comp: 0: gcc;  1: egcs;  2: pgcc, 3: apple's gcc
+ * comp: 0: gcc;  1: egcs;  2: pgcc, 3: apple's gcc, 4: clang
  */
 {
    char *cmnd, *res;
@@ -744,7 +755,9 @@ void GetGccVers(char *gcc, int *comp, int *major, int *minor, int *patch)
    free(cmnd);
    if (res)
    {
-      if (strstr(res, "Apple Computer") || strstr(res, "Apple Inc"))
+      if (strstr(res, "clang") || strstr(res, "LLVM"))
+         *comp = 4;
+      else if (strstr(res, "Apple Computer") || strstr(res, "Apple Inc"))
          *comp = 3;
 /*
  *    Skip compiler name, which may have digits in it
@@ -845,6 +858,29 @@ int CompIsGcc(char *comp)
    return(0);
 }
 
+int CompIsClang(char *comp)
+/*
+ * Tries to detect if compiler is clang w/o scoping name of compiler
+ */
+{
+   char *cmnd, *res;
+   char *cmpname;
+   int i, iret=0;
+
+   i = strlen(comp) + 16;
+   cmnd = malloc(i*sizeof(char));
+   assert(cmnd);
+   sprintf(cmnd, "%s --version", comp);
+   res = atlsys_1L(NULL, cmnd, 0, 0);
+   free(cmnd);
+   if (res)
+   {
+      iret = (strstr(res, "clang") || strstr(res, "LLVM"));
+      free(res);
+   }
+   return(iret);
+}
+
 int CompIsMinGW(char *comp)
 /*
  * Tries to detect if compiler is MinGW compiler
