@@ -77,6 +77,7 @@ enum MACHTYPE ProbeArch()
          else if (strstr(res, "7455")) mach = PPCG4;
          else if (strstr(res, "PPC970FX")) mach = PPCG5;
          else if (strstr(res, "PPC970MP")) mach = PPCG5;
+         else if (strstr(res, "POWER8")) mach = IbmPwr8;
          else if (strstr(res, "POWER7")) mach = IbmPwr7;
          else if (strstr(res, "POWER6")) mach = IbmPwr6;
          else if (strstr(res, "POWER5")) mach = IbmPwr5;
@@ -106,14 +107,82 @@ enum MACHTYPE ProbeArch()
       break;
    case AFARM:
       res = atlsys_1L(NULL, "fgrep 'Processor' /proc/cpuinfo", 0, 0);
+      if (!res)
+         res = atlsys_1L(NULL, "fgrep cpu /proc/cpuinfo", 0, 0);
+      if (!res)
+         res = atlsys_1L(NULL, "uname -a", 0, 0);
       if (res)
       {
-         if (strstr(res, "ARMv7") || strstr(res,"v7l")) mach = ARMv7;
-         free(res);
-      }
-      else if ( res=atlsys_1L(NULL, "fgrep cpu /proc/cpuinfo", 0, 0) )
-      {
-         if (strstr(res, "ARMv7") || strstr(res,"v7l")) mach = ARMv7;
+         if (strstr(res, "ARMv7") || strstr(res,"v7l"))
+         {
+            free(res);
+            res = atlsys_1L(NULL, "fgrep 'CPU part' /proc/cpuinfo", 0, 0);
+            if (res)
+            {
+               char *sp;
+               sp = strstr(res, "0x");
+               if (sp)
+               {
+                  int i;
+                  if (sscanf(sp, "%x", &i) == 1)
+                  {
+                     i &= 0xFF;
+                     switch(i)
+                     {
+                     case 7:
+                        mach = ARM7;
+                        break;
+                     case 9:
+                        mach = ARM9;
+                        break;
+                     case 15:
+                        mach = ARM15;
+                        break;
+                     case 17:
+                        mach = ARM17;
+                        break;
+                     default:;
+                     }
+                  }
+               }
+            }
+         }
+         else if (strstr(res, "AArch64") || strstr(res, "aarch64"))
+         {
+            free(res);
+            res = atlsys_1L(NULL, "fgrep 'Hardware' /proc/cpuinfo", 0, 0);
+            if (res && strstr(res, "X-Gene "))
+               mach = ARM64xg;
+            else
+            {
+               if(res)
+                  free(res);
+               res = atlsys_1L(NULL, "fgrep 'CPU part' /proc/cpuinfo", 0, 0);
+               if (res)
+               {
+                  char *sp;
+                  sp = strstr(res, "0x");
+                  if (sp)
+                  {
+                     int i;
+                     if (sscanf(sp, "%x", &i) == 1)
+                     {
+                        i &= 0xFF;
+                        switch(i)
+                        {
+                        case 3:
+                           mach = ARM64a53;
+                           break;
+                        case 7:
+                           mach = ARM64a57;
+                           break;
+                        default:;
+                        }
+                     }
+                  }
+               }
+            }
+         }
          free(res);
       }
       break;
@@ -139,8 +208,7 @@ enum MACHTYPE ProbeArch()
       {
          if (res[0] != '\0')
          {
-            if (strstr(res, "Itanium 2") || strstr(res, "McKinley") ||
-                strstr(res, "IA-64"))
+            if (strstr(res, "Itanium 2") || strstr(res, "McKinley"))
                mach = IA64Itan2;
             else if (strstr(res, "Itanium")) mach = IA64Itan;
          }
@@ -193,6 +261,8 @@ enum MACHTYPE ProbeArch()
                   mach = IntCorei3;
                else if (strstr(res, "2600") || strstr(res, "3770"))
                   mach = IntCorei2;
+               else if (strstr(res, "6700"))
+                  mach = IntCorei4;
                else
                   mach = IntCorei1;
             }
@@ -263,7 +333,10 @@ enum MACHTYPE ProbeArch()
          if (strstr(res, "2094") || strstr(res, "2096")) mach = IbmZ9;
          else if (strstr(res, "2097") || strstr(res, "2098")) mach = IbmZ10;
          /* we consider anything else to be a z196 or later */
-         else mach = IbmZ196;  /* looks risky to me, but IBM folks did it */
+         else if (strstr(res, "2817") || strstr(res, "2818")) mach = IbmZ196;
+         else if (strstr(res, "2827") || strstr(res, "2828")) mach = IbmZ12;
+         else if (strstr(res, "2964") || strstr(res, "2965")) mach = IbmZ13;
+         else mach = IbmZ13;  /* looks risky to me, but IBM folks did it */
          free(res);
       }
       break;
@@ -390,6 +463,67 @@ int ProbeMhz()
          free(res);
       }
    }
+   if (!mhz)
+   {
+      res = atlsys_1L(NULL, "cpufreq-info -f -m", 0, 0);
+      if (res)
+      {
+         char *sp;
+         sp = strstr(res, "Hz");
+         if (sp)
+         {
+           double dmhz;
+            dmhz = GetFirstDouble(res);
+            if (dmhz != 0.0)
+            {
+               switch(sp[-1])
+               {
+               case 'G':
+                  mhz = dmhz / 1000;
+                  break;
+               case ' ':
+                  mhz = dmhz / 1000000;
+                  break;
+               case 'K':
+                  mhz = dmhz / 1000;
+                  break;
+               case 'M':
+               default:
+                  mhz = dmhz;
+                  break;
+               }
+            }
+         }
+         free(res);
+      }
+   }
+   if (!mhz)
+   {
+      res = atlsys_1L(NULL, "cpufreq-info -f", 0, 0);
+      if (res)
+      {
+         mhz = GetLastInt(res);  /* assumes clock speed given in KHz */
+         free(res);
+         if (mhz)
+            mhz = mhz / 1000;
+      }
+   }
+/*
+ * RCW: Patch supplied by IBM.  I have no idea why it is written this way.
+ * S390 CPU speed is in bogomips rather than mhz
+ */
+   if (!mhz)
+   {
+      res = atlsys_1L(NULL, "cat /proc/cpuinfo | fgrep bogomips",0,0);
+      if (res)
+      {
+         double result = GetFirstDouble(res);
+         result = (result*100.0)/88.0;  /* RCW: WTF? */
+         /*if (result > 5000) result = 5000;*/
+         mhz = result;
+         free(res);
+      }
+   }
    return(mhz);
 }
 
