@@ -145,6 +145,67 @@ int ProbeMhz()
          free(res);
       }
    }
+   if (!mhz)
+   {
+      res = atlsys_1L(NULL, "cpufreq-info -f -m", 0, 0);
+      if (res)
+      {
+         char *sp;
+         sp = strstr(res, "Hz");
+         if (sp)
+         {
+           double dmhz;
+            dmhz = GetFirstDouble(res);
+            if (dmhz != 0.0)
+            {
+               switch(sp[-1])
+               {
+               case 'G':
+                  mhz = dmhz / 1000;
+                  break;
+               case ' ':
+                  mhz = dmhz / 1000000;
+                  break;
+               case 'K':
+                  mhz = dmhz / 1000;
+                  break;
+               case 'M':
+               default:
+                  mhz = dmhz;
+                  break;
+               }
+            }
+         }
+         free(res);
+      }
+   }
+   if (!mhz)
+   {
+      res = atlsys_1L(NULL, "cpufreq-info -f", 0, 0);
+      if (res)
+      {
+         mhz = GetLastInt(res);  /* assumes clock speed given in KHz */
+         free(res);
+         if (mhz)
+            mhz = mhz / 1000;
+      }
+   }
+/*
+ * RCW: Patch supplied by IBM.  I have no idea why it is written this way.
+ * S390 CPU speed is in bogomips rather than mhz
+ */
+   if (!mhz)
+   {
+      res = atlsys_1L(NULL, "cat /proc/cpuinfo | fgrep bogomips",0,0);
+      if (res)
+      {
+         double result = GetFirstDouble(res);
+         result = (result*100.0)/88.0;  /* RCW: WTF? */
+         /*if (result > 5000) result = 5000;*/
+         mhz = result;
+         free(res);
+      }
+   }
    return(mhz);
 }
 
