@@ -335,12 +335,17 @@ enum MACHTYPE Chip2Mach(enum CHIP chip, int model, int x8664)
       case 0x2D:
       case 0x3A:
       case 0x2A:
+      case 0x3E:
          iret = IntCorei2;
 	 break;
       case 0x45:
       case 0x3C:
+      case 0x3F:  /* really i3EP, but same for stable */
          iret = IntCorei3;
          break;
+      case 94:
+         iret = IntCorei4;
+         break;
       default:
          iret = MACHOther;
       }
