@@ -826,7 +826,7 @@ void SpewItForth(int verb, enum OSTYPE OS, enum MACHTYPE arch, int mhz,
 
    assert(!system("make xspew"));
    compsflags = Comps2Flags(comps);  /* Xlate comp/flag array to xspew flags */
-   i = strlen(frm) + 11*13 + strlen(srcdir) + strlen(bindir);
+   i = strlen(frm) + 11*14 + strlen(srcdir) + strlen(bindir);
    if (cdefs)
       i += strlen(cdefs);
    if (f2cdefs)
@@ -1019,7 +1019,6 @@ void GetFlags(int nargs,                /* nargs as passed into main */
    *flush = 0;
    *ptrbits = 0;
    *mhz = 0;
-   *mach = 0;
    *vec = 0;
    *asmb = 0;
    *OS = 0;
@@ -1053,6 +1052,19 @@ void GetFlags(int nargs,                /* nargs as passed into main */
             }
          }
          break;
+      case 'A':
+         if (++i >= nargs)
+            PrintUsage(args[0], i, "out of arguments");
+         if(args[i][0] >= '0' && args[i][0] <= '9') /* giving a # */
+            *mach = atoi(args[i]);
+         else /* giving a architecture name */
+         {
+            for (k=1; k < NMACH; k++)
+               if (!strcmp(args[i], machnam[k]))
+                  break;
+            *mach = (k == NMACH) ? 0 : k;
+         }
+         break;
       case 'f':
          if (++i >= nargs)
             PrintUsage(args[0], i, "out of arguments");
@@ -1068,11 +1080,6 @@ void GetFlags(int nargs,                /* nargs as passed into main */
             PrintUsage(args[0], i, "out of arguments");
          *mhz = atoi(args[i]);
          break;
-      case 'A':
-         if (++i >= nargs)
-            PrintUsage(args[0], i, "out of arguments");
-         *mach = atoi(args[i]);
-         break;
       case 'V':
          if (++i >= nargs)
             PrintUsage(args[0], i, "out of arguments");
@@ -1129,6 +1136,8 @@ void GetFlags(int nargs,                /* nargs as passed into main */
             *NoF77 = k;
          else if (!strcmp(sp0, "nocygwin"))
             *NoCygwin = k;
+         else if (!strcmp(sp0, "cripple-perf"))
+            *ThrChk = !k;
          else if (!strcmp(sp0, "kern"))
             gcc3 = sp;
          else if (!strcmp(sp0, "ADdir") || !strcmp(sp0, "addir"))
@@ -1219,7 +1228,10 @@ void GetFlags(int nargs,                /* nargs as passed into main */
          {
             if (++i >= nargs)
                PrintUsage(args[0], i, "out of arguments");
-            *gccflags = args[i];
+            if (args[i-2][1] == 'C')
+               comps[GCC_] = args[i];
+            else
+               *gccflags = args[i];
          }
          else
          {
@@ -1277,7 +1289,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
 int main(int nargs, char **args)
 {
    enum OSTYPE OS;
-   enum MACHTYPE mach;
+   enum MACHTYPE mach=MACHOther;
    int i, verb, asmb, f2cname, f2cint, f2cstr, ncpu, nof77, nocygwin;
    int thrchk, mhz, omp, AntThr, lapackref;
    int j, k, h, vecexts;
@@ -1303,6 +1315,20 @@ int main(int nargs, char **args)
       asmb = ProbeAsm(verb, targarg, OS);
    else if (asmb < 0)
       asmb = 0;
+   if (asmb == gas_arm)
+   {
+      char defs[32], *sp;
+      sprintf(defs, "-DATL_OS_%s", osnam[OS]);
+      sp = GetStrProbe(verb, defs, "ARM_HARDFP", "FPABI");
+      if (sp)
+      {
+         if (!strcmp(sp, "HARDFP"))
+            cdefs = NewAppendedString(cdefs, "-DATL_ARM_HARDFP=1");
+         else if (!strcmp(sp, "SOFTFP"))
+            cdefs = NewAppendedString(cdefs, "-DATL_ARM_SOFTFP=1");
+         free(sp);
+      }
+   }
    if (!vecexts)
       vecexts = ProbeVecs(verb, targarg, OS, asmb);
    else if (vecexts < 0)
@@ -1317,36 +1343,51 @@ int main(int nargs, char **args)
       pmake = ProbePmake(verb, OS, ncpu);
    if (ptrbits == 0)
    {
-      if (asmb == gas_x86_64)
+      if (asmb == gas_x86_64 || asmb == gas_wow64)
          ptrbits = 64;
       else
          ptrbits = ProbePtrbits(verb, targarg, OS, asmb);
    }
    if (ProbeCPUThrottle(verb, targarg, OS, asmb))
    {
+      char ln[64];
       fprintf(stderr,
          "It appears you have cpu throttling enabled, which makes timings\n");
       fprintf(stderr,
-              "unreliable and an ATLAS install nonsensical.  Aborting.\n");
-      fprintf(stderr,
-              "See ATLAS/INSTALL.txt for further information\n");
-      if (thrchk) exit(1);
-      else fprintf(stderr, "Ignoring CPU throttling by user override!\n\n");
+              "unreliable and an ATLAS install nonsensical.\n\n");
+
+      fprintf
+      (stderr,
+"OS-controlled CPU throttling is so course grained, that timings become\n"
+"essentially random.  What this means for an ATLAS install is that ATLAS\n"
+"cannot tell the difference between a good and bad kernel, and so the\n"
+"tuning step may result in arbitrarily bad performance.  If you don't care\n"
+"about performance, you are usually better off just using the reference BLAS.\n"
+"\nIf you fear overheating, setting clock speed to some lower, constant\n"
+"value should give you a decent install.\n\n"
+"Hardware-controlled throttling is usually much finer grained, and therefore\n"
+"may result in mediocre tuning, but this will depend quite bit on luck.\n\n"
+"If your machine has OS throttling enabled, it is critical that you disable\n"
+"it (with something like cpufreq-set).  See INSTALL.txt for details.\n\n"
+"If you you do not care at all about performance, you can rerun configure\n"
+"with --cripple-atlas-performance to proceed in the face of throttling.\n"
+"Do not do this unless you really don't care about performance.\n"
+"If you are able to turn off throttling, rerun configure as normal\n"
+"once you have done so.\n\n"
+      );
+      if (thrchk)
+      {
+         fprintf(stderr, "Aborting due to throttling\n");
+         exit(1);
+      }
    }
 /*
  * Override 32/64 bit assembler if asked
  */
-   if (asmb == gas_x86_64 && ptrbits == 32)
+   if ((asmb == gas_x86_64 || asmb == gas_wow64) && ptrbits == 32)
       asmb = gas_x86_32;
    else if (asmb == gas_x86_32 && ptrbits == 64)
       asmb = gas_x86_64;
-/*
- * Now that we've detected architecture stuff, kill assembly dialect for
- * 64-bit install of Win64, since we can't use our normal AMD64 assembly
- * there due to incompatable ABI
- */
-   if (OS == OSWin64 && ptrbits == 64)
-      asmb = ASM_None;
 
    sp = ProbeComp(verb, targarg, OS, mach, comps, nof77, nocygwin, ptrbits,
                   vecexts);
