@@ -121,7 +121,7 @@ int ProbeOneInt(enum OSTYPE OS0, enum ASMDIA asmd0, char *targ0,
 /*
  * If Assembler right or unspecified, try x86 probe
  */
-   if (asmd == gas_x86_32 || asmd == gas_x86_64)
+   if (asmd == gas_x86_32 || asmd == gas_x86_64 || asmd == gas_wow64)
    {
       frm = "make IRunArchInfo_x86 MYFLAGS=\"-DATL_OS_%s -DATL_%s\" args=\"%s\" %s | fgrep '%s'";
       i = strlen(frm) + strlen(osnam[OS]) + strlen(ASMNAM[asmd]) + strlen(flag)
@@ -227,7 +227,8 @@ int main(int nargs, char **args)
    if (flags & Parch)
    {
       arch = ProbeOneInt(OS, asmd, targ, "-a", "MACHTYPE=", &sure);
-      if (arch == MACHOther && (asmd == gas_x86_32 || asmd == gas_x86_64))
+      if (arch == MACHOther &&
+          (asmd == gas_x86_32 || asmd == gas_x86_64 || asmd == gas_wow64))
          arch = x86X;
       if (flags & Pverb)
          printf("Architecture detected as %s.\n", machnam[arch]);
@@ -243,7 +244,7 @@ int main(int nargs, char **args)
              ProbeOneInt(OS, asmd, targ, "-t", "CPU THROTTLE=", &sure));
    if (flags & P64)
    {
-      if (asmd == gas_x86_64)
+      if (asmd == gas_x86_64 || asmd == gas_wow64)
       {
          sure = 1;
          bits = 64;
