@@ -452,6 +452,8 @@ COMPNODE **GetDefaultComps(enum OSTYPE OS, enum MACHTYPE arch, int verb,
       vp = "-mavx2 -mfma";
    else if (vecexts & (1<<ISA_VSX))
       vp = "-mvsx";
+   else if (vecexts & (1<<ISA_VXZ))
+      vp = "-mvx -mzvector";
    else if (vecexts & (1<<ISA_AV))
       vp = "-maltivec";
    else if (vecexts & (1<<ISA_AVX))
@@ -462,6 +464,14 @@ COMPNODE **GetDefaultComps(enum OSTYPE OS, enum MACHTYPE arch, int verb,
       vp = "-msse2";
    else if (vecexts & (1<<ISA_SSE1))
       vp = "-msse";
+   else if (vecexts & (1<<ISA_NEON))
+      vp = "-mfpu=neon";
+   else if (vecexts & (1<<ISA_NEON16))
+      vp = "-mfpu=neon-fp16";
+   else if (vecexts & (1<<ISA_VFP3D32MAC))
+      vp = "-mfpu=vfpv3";
+   else if (vecexts & (1<<ISA_VFP3D16MAC))
+      vp = "-mfpu=vfpv3-d16";
    comps = malloc(sizeof(COMPNODE)*NCOMP);
    q = ReadComps("atlcomp.txt");    /* get all compiler lines */
    if (verb > 1)
@@ -499,7 +509,8 @@ COMPNODE **GetDefaultComps(enum OSTYPE OS, enum MACHTYPE arch, int verb,
                else if (strstr(p->comp, "gcc"))
                   p->flags = NewAppendedString(p->flags, vp);
             #else
-               if (strstr(p->comp, "gcc") || strstr(p->comp, "gfortran"))
+               if (strstr(p->comp, "gcc") || strstr(p->comp, "gfortran") ||
+                   strstr(p->comp, "clang"))
                   p->flags = NewAppendedString(p->flags, vp);
             #endif
          }
@@ -588,6 +599,9 @@ char *GetPtrbitsFlag(enum OSTYPE OS, enum MACHTYPE arch, int ptrbits,
       return((ptrbits == 64) ? "-mabi=64" : "-mabi=n32");
    if (MachIsS390(arch))
       return((ptrbits == 64) ? "-m64" : "-m31");
+   if (OS == OSAIX)
+      return((ptrbits == 64) ? "-maix64" : "-maix32");
+
    if (!CompIsGcc(comp))
    {
 /*
@@ -621,7 +635,7 @@ char *GetPtrbitsFlag(enum OSTYPE OS, enum MACHTYPE arch, int ptrbits,
    }
    return(sp);
 }
-char *GetStandardCompName(char *comp)
+char *GetStandardCompName(char *comp, int f77)
 {
    int i, j, k;
    char *ucomp;
@@ -632,29 +646,24 @@ char *GetStandardCompName(char *comp)
    {
       GetGccVers(comp, &k, &j, &k, &k);
       if (j < 4)
-      {
-         if (i == F77_)
-            ucomp = "g77";
-         else
-            ucomp = "gcc";
-      }
-      else if (i == F77_)
-         ucomp = "gfortran";
+         ucomp = (f77) ? "g77" : "gcc";
       else
-         ucomp = "gcc";
+         ucomp = (f77) ? "gfortran" : "gcc";
    }
+   else if (CompIsClang(comp))
+      ucomp = (f77) ? "gfortran" : "clang";
    else
       ucomp = NameWithoutPath(comp);
    return(ucomp);
 }
-char *GetWinComp(enum OSTYPE OS, char *comp, char *bindir)
+char *GetWinComp(enum OSTYPE OS, char *comp, char *bindir, int if77)
 {
    char *ln;
    char *ucomp;
    int i;
    if (!OSIsWin(OS))
       return(NULL);
-   ucomp = GetStandardCompName(comp);
+   ucomp = GetStandardCompName(comp, if77);
    if (!strcmp(ucomp, "icc") || !strcmp(ucomp, "icl"))
       ucomp = "ATLwin_icc";
    else if (!strcmp(ucomp, "ifort") || !strcmp(ucomp, "ivf"))
@@ -841,6 +850,7 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
    char *ucomp, *dcomp, *flg, *sp, *sp2, *mgwd=NULL, *mgwc=NULL, *mgwf=NULL;
    char *cmnd, *res;
    int i, j, k, h;
+   const int WIN64_32 = (OS == OSWin64 && ptrbits == 32);
 /*
  * Look through input compilers; any of them that is simply "gcc" gets replaced
  * with goodgcc;  If user has overridden with path or specific name (gcc-4)
@@ -859,10 +869,9 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
    }
 
 /*
- * If the user requests MinGW install, or is on 64-bit platform, build
- * wrapper code
+ * If the user requests MinGW install build wrapper code
  */
-   if (nocygwin || (OS == OSWin64 && ptrbits == 64))
+   if (nocygwin)
    {
       int fndit;
       mgwd = SetupMinGW(verb, ptrbits, nof77);
@@ -912,7 +921,7 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
             flg = NewStringCopy(usrcomps[NCOMP+i]?usrcomps[NCOMP+i]:p->flags);
             if (usrcomps[NCOMP*2+i])
                flg = NewAppendedString(flg, usrcomps[NCOMP*2+i]);
-            freeme = sp = GetWinComp(OS, p->comp, bindir);
+            freeme = sp = GetWinComp(OS, p->comp, bindir, (i==F77_));
             if (!sp)
             {
 /*
@@ -934,13 +943,10 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
                else
                   sp = p->comp;
             }
-            if (ptrbits)
+            if (ptrbits && (!WIN64_32 || i != XCC_))
             {
-               if (OS == OSWin64 && ptrbits == 64 && i == XCC_)
-                  flg = NewAppendedString(flg, "-m32");
-               else
-                  flg = NewAppendedString(flg,
-                           GetPtrbitsFlag(OS, arch, ptrbits, sp));
+               flg = NewAppendedString(flg,
+                        GetPtrbitsFlag(OS, arch, ptrbits, sp));
             }
             if (sp == mgwf)
                flg = NewAppendedString(flg, "-static");
@@ -975,25 +981,7 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
       else if (!usrcomps[NCOMP+i])
       {
          p = comps[i];
-         ucomp = NameWithoutPath(usrcomps[i]);
-/*
- *       Recognize gnu compiler regardless of name string (eg. ev6-gcc-3.2)
- */
-         if (CompIsGcc(usrcomps[i]))
-         {
-            GetGccVers(usrcomps[i], &k, &j, &k, &k);
-            if (j < 4)
-            {
-               if (i == F77_)
-                  ucomp = "g77";
-               else
-                  ucomp = "gcc";
-            }
-            else if (i == F77_)
-               ucomp = "gfortran";
-            else
-               ucomp = goodgcc;
-         }
+         ucomp = GetStandardCompName(usrcomps[i], (i==F77_));
          for (p=comps[i]; p; p = p->next)
          {
             dcomp = NameWithoutPath(p->comp);
@@ -1014,7 +1002,7 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
 /*
  *    On windows, build compiler wrapper for MSVC++ or Intel compilers
  */
-      sp = GetWinComp(OS, usrcomps[i], bindir);
+      sp = GetWinComp(OS, usrcomps[i], bindir, (i==F77_));
       if (sp)
       {
          free(usrcomps[i]);
@@ -1026,13 +1014,10 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
       flg = NewStringCopy(usrcomps[NCOMP+i]?usrcomps[NCOMP+i]:p->flags);
       if (usrcomps[NCOMP*2+i])
          flg = NewAppendedString(flg, usrcomps[NCOMP*2+i]);
-      if (ptrbits)
+      if (ptrbits && (!WIN64_32 || i != XCC_))
       {
-         if (OS == OSWin64 && ptrbits == 64 && i == XCC_)
-            flg = NewAppendedString(flg, "-m32");
-         else
-            flg = NewAppendedString(flg,
-                     GetPtrbitsFlag(OS, arch, ptrbits,usrcomps[i]));
+         flg = NewAppendedString(flg,
+                                 GetPtrbitsFlag(OS, arch, ptrbits,usrcomps[i]));
       }
       if (strstr(usrcomps[i], "mgwgfortran"))
          flg = NewAppendedString(flg, "-static");
@@ -1068,9 +1053,6 @@ void GetComps(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
       for (i=0; i < NCOMP; i++)
       {
          sp = GetPtrbitsFlag(OS, arch, ptrbits, usrcomps[i]);
-         if (OS == OSWin64 && ptrbits == 64 && i == XCC_)
-            usrcomps[i+NCOMP] = NewAppendedString(usrcomps[i+NCOMP], "-m32");
-         else
             usrcomps[i+NCOMP] = NewAppendedString(usrcomps[i+NCOMP], sp);
       }
    }
@@ -1139,7 +1121,8 @@ int SelectBestGcc
    char *targ,
    int GMAJOR,
    int GMINOR,
-   char **gccs   /* NULL-terminated list of possible gcc compilers */
+   char **gccs,  /* NULL-terminated list of possible gcc compilers */
+   int USEMINGW  /* 0/1: reject/accept MINGW compilers */
 )
 /*
  * RETURNS: 0 if no gcc compiler,
@@ -1154,6 +1137,8 @@ int SelectBestGcc
    for (i=0; gccs[i]; i++)
    {
       int icmp, major, minor, patch;
+      if (!USEMINGW && CompIsMinGW(gccs[i]))
+         continue;
       GetGccVers(gccs[i], &icmp, &major, &minor, &patch);
       if (verb)
          printf("   icmp=%d, maj=%d, min=%d, pat=%d: %s\n",
@@ -1220,6 +1205,45 @@ void GetBestGccVers(enum OSTYPE OS, enum MACHTYPE arch,
    *GMAJOR = 4;
    switch(arch)
    {
+   case IbmZ12:
+   case IbmZ13:
+   case IntCorei3:
+   case IntCorei4:
+   case IntCorei2:
+      *GMAJOR = 6;
+      *GMINOR = 1;
+      *GPATCH = 0;
+      break;
+   case IbmPwr7:
+       *GMAJOR = 4;
+       *GMINOR = 8;
+       *GPATCH = 3;
+       break;
+   case IbmPwr8:
+       *GMAJOR = 5;
+       *GMINOR = 3;
+       *GPATCH = 1;
+       break;
+   case ARM64xg:
+       *GMAJOR = 5;
+       *GMINOR = 3;
+       *GPATCH = 0;
+       break;
+   case ARM7:
+       *GMAJOR = 4;
+       *GMINOR = 9;
+       *GPATCH = 2;
+       break;
+   case ARM9:
+       *GMAJOR = 4;
+       *GMINOR = 7;
+       *GPATCH = 2;
+       break;
+   case ARM15:
+       *GMAJOR = 4;
+       *GMINOR = 8;
+       *GPATCH = 4;
+       break;
    case PPCG4:          /* cannot install 4.7.0 */
    case PPCG5:          /* cannot install 4.7.0 */
    case SunUSII:        /* cannot install 4.7.0 */
@@ -1232,20 +1256,17 @@ void GetBestGccVers(enum OSTYPE OS, enum MACHTYPE arch,
    case x86SSE2:
    case x86SSE3:
    case x86x87:
-   case IbmPwr7:
    case IntCore2:
    case IntCorei1:
-   case IntCorei2:
-   case IntCorei3:
    case Amd64K10h:
-   case ARMv7:
    default:
       *GMINOR = 7;
       *GPATCH = 0;
       break;
    }
 }
-char *FindGoodGcc(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ)
+char *FindGoodGcc(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ,
+                  int USEMINGW)
 {
    char *OSpaths=NULL, *sp, **gccs=NULL;
    char *ln;
@@ -1273,7 +1294,7 @@ char *FindGoodGcc(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ)
       sprintf(ln, "find %s -maxdepth 1 -name '*gcc*' -exec ./xisgcc '{}' \\;",
               OSpaths);
       gccs = GetLinesFromFile(atlsys(NULL, ln, verb, 1), gccs);
-      i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs);
+      i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs, USEMINGW);
       if (i > 1)
       {
          free(ln);
@@ -1303,7 +1324,7 @@ char *FindGoodGcc(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ)
       if (fp)
       {
          gccs = GetLinesFromFile(fp, gccs);
-         i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs);
+         i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs, USEMINGW);
          if (i > 0)
          {
             free(ln);
@@ -1327,7 +1348,7 @@ char *FindGoodGcc(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ)
    if (fp)
    {
       gccs = GetLinesFromFile(fp, gccs);
-      i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs);
+      i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs, USEMINGW);
       if (i > 0)
       {
          free(ln);
@@ -1353,7 +1374,7 @@ char *FindGoodGcc(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ)
       i = sprintf(ln, "find %s -name '*gcc*' -exec ./xisgcc '{}' \\;",
                   stdpaths);
       gccs = GetLinesFromFile(atlsys(NULL, ln, verb, 1), gccs);
-      i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs);
+      i = SelectBestGcc(verb, targ, GMAJOR, GMINOR, gccs, USEMINGW);
       if (i > 1)
       {
          free(ln);
@@ -1372,7 +1393,7 @@ char *FindGoodGcc(enum OSTYPE OS, enum MACHTYPE arch, int verb, char *targ)
 }
 
 char *FindGoodGfortran(enum OSTYPE OS, enum MACHTYPE arch, int verb,
-                       char *targ, char *gcc)
+                       char *targ, char *gcc, int USEMINGW)
 {
    char *OSpaths=NULL, *sp, **gccs=NULL;
    char *ln;
@@ -1397,7 +1418,7 @@ char *FindGoodGfortran(enum OSTYPE OS, enum MACHTYPE arch, int verb,
       sprintf(ln,
          "find %s -maxdepth 1 -name '*gfortran*' -exec ./xisgcc '{}' \\;", sp);
       gccs = GetLinesFromFile(atlsys(NULL, ln, verb, 1), gccs);
-      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs);
+      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs, USEMINGW);
       if (i > 1)
       {
          free(ln);
@@ -1430,7 +1451,7 @@ char *FindGoodGfortran(enum OSTYPE OS, enum MACHTYPE arch, int verb,
          "find %s -maxdepth 1 -name '*gfortran*' -exec ./xisgcc '{}' \\;",
          OSpaths);
       gccs = GetLinesFromFile(atlsys(NULL, ln, verb, 1), gccs);
-      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs);
+      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs, USEMINGW);
       if (i > 1)
       {
          free(ln);
@@ -1457,7 +1478,7 @@ char *FindGoodGfortran(enum OSTYPE OS, enum MACHTYPE arch, int verb,
          "find %s -maxdepth 1 -name '*gfortran*' -exec ./xisgcc '{}' \\;", sp);
       free(sp);
       gccs = GetLinesFromFile(atlsys(NULL, ln, verb, 1), gccs);
-      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs);
+      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs, USEMINGW);
       if (i > 0)
       {
          free(ln);
@@ -1480,7 +1501,7 @@ char *FindGoodGfortran(enum OSTYPE OS, enum MACHTYPE arch, int verb,
    if (fp)
    {
       gccs = GetLinesFromFile(fp, gccs);
-      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs);
+      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs, USEMINGW);
       if (i > 0)
       {
          free(ln);
@@ -1508,7 +1529,7 @@ char *FindGoodGfortran(enum OSTYPE OS, enum MACHTYPE arch, int verb,
       i = sprintf(ln, "find %s -name '*gfortran*' -exec ./xisgcc '{}' \\;",
                    stdpaths);
       gccs = GetLinesFromFile(atlsys(NULL, ln, verb, 1), gccs);
-      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs);
+      i = SelectBestGcc(verb, targ, cmaj, cmin, gccs, USEMINGW);
       if (i > 1)
       {
          free(ln);
@@ -1755,7 +1776,6 @@ void GetFlags(int nargs,                /* nargs as passed into main */
       comps[k] = NULL;
 
    *ptrbits = 0;
-   *mach = 0;
    *vec = 0;
    *OS = 0;
    *verb = 0;
@@ -1767,16 +1787,24 @@ void GetFlags(int nargs,                /* nargs as passed into main */
          PrintUsage(args[0], i, args[i]);
       switch(args[i][1])
       {
+      case 'A':
+         if (++i >= nargs)
+            PrintUsage(args[0], i, "out of arguments");
+         if(args[i][0] >= '0' && args[i][0] <= '9') /* giving a # */
+            *mach = atoi(args[i]);
+         else /* giving a architecture name */
+         {
+            for (k=1; k < NMACH; k++)
+               if (!strcmp(args[i], machnam[k]))
+                  break;
+            *mach = (k == NMACH) ? 0 : k;
+         }
+         break;
       case 'b':
          if (++i >= nargs)
             PrintUsage(args[0], i, "out of arguments");
          *ptrbits = atoi(args[i]);
          break;
-      case 'A':
-         if (++i >= nargs)
-            PrintUsage(args[0], i, "out of arguments");
-         *mach = atoi(args[i]);
-         break;
       case 'V':
          if (++i >= nargs)
             PrintUsage(args[0], i, "out of arguments");
@@ -1967,28 +1995,10 @@ int main(int nargs, char **args)
    }
    else
       targarg = "";
-   #if defined(ATL_GCCCLANG) || defined(ATL_GCC3P)
-   {
-      char *topd;
-      int dlen;
-      topd = atlsys_1L(NULL, "pwd", verb, 1);
-      assert(topd);
-      dlen = strlen(topd);
-      goodgcc = malloc(dlen + 10);
-      assert(goodgcc);
-      #ifdef ATL_GCCCLANG
-         sprintf(goodgcc, "%s/gccclang", topd);
-      #else
-         sprintf(goodgcc, "%s/gcc3p", topd);
-      #endif
-      free(topd);
-   }
-   #else
-      if (usrcomps[GCC_])
-         goodgcc = NewStringCopy(usrcomps[GCC_]);
-      else
-         goodgcc = FindGoodGcc(OS, mach,  verb, targ);
-   #endif
+   if (usrcomps[GCC_])
+      goodgcc = NewStringCopy(usrcomps[GCC_]);
+   else
+      goodgcc = FindGoodGcc(OS, mach,  verb, targ, nocygwin);
    GetComps(OS, mach, verb, targ, ptrbits, usrcomps, nof77, nocygwin, vecexts,
             goodgcc, bindir);
 /*
@@ -1997,7 +2007,7 @@ int main(int nargs, char **args)
    if (!nof77 && usrcomps[F77_] && !strcmp(usrcomps[F77_], "gfortran"))
    {
       free(usrcomps[F77_]);
-      usrcomps[F77_] = FindGoodGfortran(OS, mach, verb, targ, goodgcc);
+      usrcomps[F77_] = FindGoodGfortran(OS, mach, verb, targ, goodgcc,nocygwin);
       if (!usrcomps[F77_])
          usrcomps[F77_] = NewStringCopy("gfortran");
    }
