@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 2000 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -419,11 +419,15 @@ static TYPE diffnrm(const int N, const TYPE *X1, const TYPE *X2)
       #ifdef TREAL
          t0 = X1[i] - X2[i];
          t0 = Mabs(t0);
+         if (t0 != t0)
+            return(t0);
          if (t0 > max) max = t0;
       #else
          t0 = X1[2*i] - X2[2*i]; t1 = X1[2*i+1] - X2[2*i+1];
          t0 = Mabs(t0); t1 = Mabs(t1);
          t0 += t1;
+         if (t0 != t0)
+            return(t0);
          if (t0 > max) max = t0;
       #endif
    }
