@@ -10,7 +10,15 @@
       #define ATL_AVgcc
    #endif
    #ifdef ATL_AVgcc
-      #include <altivec.h>
+      #ifdef ATL_VSX390 /* part of broken IBM Z patch, presently never deffed */
+         #if defined (__IBMC__) || defined (__IBMCPP__)
+            #include <builtins.h>
+         #else
+            #include <vecintrin.h>
+         #endif
+      #else
+         #include <altivec.h>
+      #endif
 
       #define VECTOR_INIT(v0_,v1_,v2_,v3_) (vector float) {v0_,v1_,v2_,v3_}
       #define VECTOR_INITI(v0_,v1_,v2_,v3_) (vector int) {v0_,v1_,v2_,v3_}
