@@ -154,7 +154,8 @@
    #define ATL_GOT_L1PREFETCH
    #define ATL_L1LS 32
    #define ATL_L2LS 64
-#elif defined(ATL_ARCH_IbmZ196) || defined(ATL_ARCH_IbmZ10)
+#elif defined(ATL_ARCH_IBMz196) || defined(ATL_ARCH_IBMz10) || \
+      defined(ATL_ARCH_IBMzEC12) || defined(ATL_ARCH_IBMz13)
    #define ATL_pfl1R(mem) __builtin_prefetch(mem, 0, 3)
    #define ATL_pfl1W(mem) __builtin_prefetch(mem, 1, 3)
    #define ATL_GOT_L1PREFETCH
