@@ -786,8 +786,9 @@ static void PrintR1Line(FILE *fpout, ATL_r1node_t *np)
    if (i > 70) { fprintf(fpout, " \\\n   "); i = 3; }
    i += fprintf(fpout, "X87=%d ", FLAG_IS_SET(np->flag, R1F_X87));
 
-   if (np->mflop[0]+np->mflop[1]+np->mflop[2]+np->mflop[3]+np->mflop[4]+
-       np->mflop[5]+np->mflop[6] != 0.0)
+   if (np->mflop[0] != 0.0 || np->mflop[1] != 0.0 || np->mflop[2] != 0.0 ||
+       np->mflop[3] != 0.0 || np->mflop[4] != 0.0 || np->mflop[5] != 0.0 ||
+       np->mflop[6] != 0.0)
    {
       if (i > 3) { fprintf(fpout, " \\\n   "); i = 3; }
       i += fprintf(fpout, "MFLOP=%le", np->mflop[0]);
