@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -135,7 +135,7 @@ void col2blk2(const int M, const int N, const TYPE *A, const int lda, TYPE *V,
 {
    int j;
    const int nNb = ATL_DivByNB(N), jb = N - ATL_MulByNB(nNb);
-   const int incA = (lda*NB)<<1, incV = (M*NB)<<1;
+   size_t incA = (lda*NB)<<1, incV = (M*NB)<<1;
 
    for (j=nNb; j; j--)
    {
