@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 2003 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -147,7 +147,8 @@ int ATL_pmmJIK(const enum PACK_UPLO UA, const enum ATLAS_TRANS TA,
          if (jb != NB || ib != MB)
          {
             pNBmm0 = pNBmm = ATL_gNBmm;
-            if (ib != NB && jb != NB) Mjoin(PATL,gezero)(MB, NB, pC, MB);
+            if ((!nKb && kb != NB) || (ib != NB && jb != NB))
+               Mjoin(PATL,gezero)(MB, NB, pC, MB);
          }
          else
          {
@@ -304,7 +305,8 @@ int ATL_pmmJIKF(const enum PACK_UPLO UA, const enum ATLAS_TRANS TA,
          if (jb != NB || ib != MB)
          {
             pNBmm0 = pNBmm = ATL_gNBmm;
-            if (ib != NB && jb != NB) Mjoin(PATL,gezero)(MB, NB, pC, MB);
+            if ((!nKb && kb != NB) || (ib != NB && jb != NB))
+               Mjoin(PATL,gezero)(MB, NB, pC, MB);
          }
          else
          {
