@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 2003 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -325,7 +325,7 @@ int Mjoin(PATL,prk_kmm)(const enum ATLAS_UPLO UC,
          pA = pC + NBNB2 + i*(K SHIFT);
          ib = N-i;
          ib = Mmin(ib, NB);
-         if (ib != NB || jb != NB)
+         if ((!nKb && kb != NB) || (ib != NB || jb != NB))
             Mjoin(PATL,gezero)(ib, jb, pC, ib);
          if (nKb)
          {
