@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 2003 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -344,7 +344,7 @@ int Mjoin(PATL,phk_kmm)(const enum ATLAS_UPLO UC,
          pA = pC + NBNB2 + incK + i*K2;
          ib = N-i;
          ib = Mmin(ib, NB);
-         if (ib != NB || jb != NB)
+         if ((!nKb && kb != NB) || (ib != NB || jb != NB))
             Mjoin(PATL,gezero)(ib, jb, pC, ib);
          if (nKb)
          {
