@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                   (C) Copyright 1999 Antoine P. Petitet
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,6 +55,8 @@ const TYPE *A, const int LDA)
          t0 += Mabs( A[iaij] ) + Mabs( A[iaij+1] );
 #endif
       }
+      if (t0 != t0)
+         return(t0);
       if (t0 > max) max = t0;
    }
    return(max);
