@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,6 +43,8 @@ TYPE Mjoin(PATL,genrm1)(const int M, const int N, const TYPE *A, const int lda)
    for (j=0; j < N; j++)
    {
       t0 = Mjoin(PATL,asum)(M, A, 1);
+      if (t0 != t0)
+         return(t0);
       if (t0 > max) max = t0;
       A += lda2;
    }
