@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                   (C) Copyright 1999 Antoine P. Petitet
  *
  * Redistribution and use in source and binary forms, with or without
@@ -93,7 +93,9 @@ TYPE Mjoin(PATL,synrm)
    }
 
    max = work[0];
-   for( j = 1; j < N; j++ ) if( max < work[j] ) max = work[j];
+   for(j = 1; j < N; j++)
+      if (work[j] != work[j] || max < work[j])
+         max = work[j];
 
    if( work ) free( work );
 
