@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                   (C) Copyright 1999 Antoine P. Petitet
  *
  * Redistribution and use in source and binary forms, with or without
@@ -53,6 +53,8 @@ TYPE Mjoin(PATL,tpnrm1)(const enum ATLAS_UPLO UPLO, const enum ATLAS_DIAG DIAG,
             t0 += Mabs( A[iaij] ) + Mabs( A[iaij+1] );
 #endif
          }
+         if (t0 != t0)
+            return(t0);
          if( DIAG == AtlasNonUnit ) t0 += ATL_rone;
          if (t0 > max) max = t0;
          iaij += (1 SHIFT);
@@ -73,6 +75,8 @@ TYPE Mjoin(PATL,tpnrm1)(const enum ATLAS_UPLO UPLO, const enum ATLAS_DIAG DIAG,
             t0 += Mabs( A[iaij] ) + Mabs( A[iaij+1] );
 #endif
          }
+         if (t0 != t0)
+            return(t0);
          if (t0 > max) max = t0;
 
          iaij -= ( ( N - j ) << (1 SHIFT) ) + (1 SHIFT);
