@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                   (C) Copyright 1999 Antoine P. Petitet
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,6 +47,8 @@ TYPE Mjoin(PATL,trnrm1)(const enum ATLAS_UPLO Uplo, const enum ATLAS_DIAG Diag,
       for (j=0; j < N; j++)
       {
          t0 = Mjoin(PATL,asum)(j+ioff, A, 1);
+         if (t0 != t0)
+            return(t0);
          if (Diag == AtlasUnit) t0 += ATL_rone;
          if (t0 > max) max = t0;
          A += incA;
@@ -58,6 +60,8 @@ TYPE Mjoin(PATL,trnrm1)(const enum ATLAS_UPLO Uplo, const enum ATLAS_DIAG Diag,
       for (j=N; j; j--)
       {
          t0 = Mjoin(PATL,asum)(j+ioff-1, A, 1);
+         if (t0 != t0)
+            return(t0);
          if (Diag == AtlasUnit) t0 += ATL_rone;
          if (t0 > max) max = t0;
          A += incA;
