@@ -573,8 +573,10 @@ void Mjoin(PATL,tgemm)(const enum ATLAS_TRANS TA, const enum ATLAS_TRANS TB,
  * of dynamic scheduling, which always seems to pay for itself.
  * On unloaded AMD machines, the asymptotic loss is roughly 1-2%.
  * Dynamic scheduling seems to always be a performance loss for MAC OSX
+ * These routines require strongly-ordered caches, so only enable on x86.
  */
-   #ifndef ATL_OS_OSX
+   #if !defined(ATL_OS_OSX) && (defined(ATL_GAS_x8664) || \
+       defined(ATL_GAS_WOW64) || defined(ATL_GAS_x8632))
       #ifdef FindingCE
          ATL_assert(!Mjoin(PATL,tgemm_bigMN_Kp)(TA, TB, M, N, K, alpha, A, lda,
                                                 B, ldb, beta, C, ldc));
