@@ -70,7 +70,11 @@ static void DoMM_K
       return;
    }
    if (mb != NB && nb != NB)
+   {
+      if (SCALAR_IS_ZERO(beta))
+         Mjoin(PATL,gezero)(mb, nb, C, ldc);
       mmk_bX = mmk = genmm;
+   }
    else if (mb != NB)
    {
       mmk = PMBmm;
