@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  * Copyright (C) 2012 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -137,7 +137,7 @@ void ATL_USERMM (const int M, const int N, const int K, const TYPE alpha,
 #include "atlas_asm.h"
 .code 32
 .fpu vfpv3
-#ifdef ATL_ARM_HARDFP
+#ifndef ATL_ARM_SOFTFP
 .eabi_attribute 28, 1
 #endif
 .text
@@ -154,7 +154,7 @@ ATL_asmdecor(ATL_USERMM):
 /*
  * Load needed vals to registers
  */
-#ifdef ATL_ARM_HARDFP
+#ifndef ATL_ARM_SOFTFP
    add M0, SP, #FSIZE
    ldmIA M0, {lda,pB0,pA1,pC0,ldc}      /* lda,B,ldb,C,ldc */
    vmov.32 M0, d0[1]                    /* put beta in M0 */
@@ -214,7 +214,7 @@ ATL_asmdecor(ATL_USERMM):
          #else
             add PTR, pC0, ldc
             #ifdef BETAX
-               #ifdef ATL_ARM_HARDFP
+               #ifndef ATL_ARM_SOFTFP
                   flds rb0, [SP, #0]
                #else
                   flds rb0, [SP, #(FSIZE+16)]
@@ -387,7 +387,7 @@ ATL_asmdecor(ATL_USERMM):
       mov M, M0
    bne NLOOP
 
-   #ifdef ATL_ARM_HARDFP
+   #ifndef ATL_ARM_SOFTFP
       pop {r0}  /* clear beta off stack */
    #endif
    add SP, SP, #VSIZE
