@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
  *               2007, 2008, 2009, 2010 R. Clint Whaley
  *
@@ -2986,7 +2986,8 @@ int GetNumRegsMM(char pre, int MaxL1Size, int MAX_NREG)
               "FOUND # OF REGISTERS TO BE %d; TRYING 8 FOR SAFETY.\n", nreg);
       nreg = 8;
    }
-#if !defined (ATL_GAS_x8632) && !defined(ATL_GAS_x8664)
+#if !defined (ATL_GAS_x8632) && !defined(ATL_GAS_x8664) && \
+    !defined(ATL_GAS_WOW64)
    else if (nreg < 16)
    {
       fprintf(stderr,
