@@ -56,6 +56,42 @@ int CountFlagNodes(ATL_flagnode_t *bp)
    return(i);
 }
 
+ATL_flagnode_t *GetClangOptFlags(void)
+{
+   char *gccflags[] =
+{"REPLACE THIS LINE WT ARCH-DEP FLAGS ALWAYS USED (eg, -mfpmath=sse -msse3)",
+ "4", "-O2", "-O1", "-O3", "-Os",
+ "0",
+ "# Flags to probe once optimization level is selected",
+ "-freroll-loops",
+ "-fno-reroll-loops",
+ "-funroll-loops",
+ "-fno-unroll-loops",
+ "-adce", "-dce",
+ "-die",
+ "-dse",
+ "-indvars",
+ "-ldcssa",
+ "-licm",
+ "-loop-reduce",
+ "-loop-rotate",
+ "-loop-simplify",
+ "-loop-unroll",
+ "-loop-unswitch",
+ NULL
+};
+   int i;
+   ATL_flagnode_t *bp, *pf;
+
+   pf = bp = NewFlagNode(gccflags[0]);
+   for (i=1; gccflags[i]; i++)
+   {
+      pf->next = NewFlagNode(gccflags[i]);
+      pf = pf->next;
+   }
+   return(bp);
+}
+
 ATL_flagnode_t *GetGccOptFlags(void)
 {
    char *gccflags[] =
@@ -226,7 +262,7 @@ char *ReadFlags
    ln = ReadFlagLine(fpin);
    n = strtol(ln, NULL, 0);
    if (!n || !lvls)
-      optflags = NULL;
+      oflags = NULL;
    else
    {
       ln = ReadFlagLine(fpin);
@@ -362,13 +398,21 @@ char GetFlags(int nargs, char **args, int *verb,
       case 'f':  /* flag file */
          if (++i >= nargs)
             PrintUsage(args[0], i, NULL);
-         if (!strcmp(args[i], "gcc"))
+         if (!strcmp(args[i], "gcc") || !strcmp(args[i], "clang"))
          {
             FILE *fpout;
             ATL_flagnode_t *bp, *fp;
-            fpout = fopen("gccflags.txt", "w");
+            if (!strcmp(args[i], "clang"))
+            {
+               fpout = fopen("clangflags.txt", "w");
+               bp = GetClangOptFlags();
+            }
+            else
+            {
+               fpout = fopen("gccflags.txt", "w");
+               bp = GetGccOptFlags();
+            }
             assert(fpout);
-            bp = GetGccOptFlags();
             for (fp=bp; fp; fp = fp->next)
                fprintf(fpout, "%s\n", fp->flags);
             fclose(fpout);
@@ -693,8 +737,8 @@ int main(int nargs, char **args)
       PrintMMLine(stdout, mmp);
    }
    baseflags = ReadFlags(fpflag, &optlvls, &lvlflags, &flags);
-   GreedyLinearFlagSearch(pre, verb, NULL, 1.01, mmp, baseflags, optlvls,
-                          lvlflags, flags);
+   baseflags = GreedyLinearFlagSearch(pre, verb, NULL, 1.01, mmp, baseflags,
+                                      optlvls, lvlflags, flags);
    KillAllFlagNodes(lvlflags);
    KillAllFlagNodes(optlvls);
    KillAllFlagNodes(flags);
