@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 1997 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -56,6 +56,12 @@ enum ATLAS_MATSHAPE {AtlasM_NB=0, AtlasN_NB=1, AtlasMN_NB=2, AtlasK_NB=3,
 
 #define DENMAT 175
 #define MAXALLOC (8*1024*1024*8)
+#if MAXALLOC < 3*L2SIZE
+   #undef MAXALLOC
+   #define MAXALLOC (3*L2SIZE)
+#endif
+
+
 
 #ifdef ATL_DeclareSlens
 F77_INTEGER ATL_Slen1, ATL_Slen2;
