@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.2
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  * Copyright (C) 2010 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -206,7 +206,7 @@ int RecDoubleNX
    double t0, tL, tN;  /* 0, Last, Next */
    double tB, tE, tM;  /* beginning, end, middle timings */
    ATL_INT n0, nL, nN;
-   ATL_INT nB, nE, nM;
+   ATL_INT nB, nE, nM=0;
 
    t0 = GetTimes(Uplo, verb, nsample, nreps, flushelts, N, N);
    printf("\n   Time for N=NX=%d : %e\n", N, t0);
