@@ -538,7 +538,7 @@ FILENODE *TstFile(char pre, FILENODE *fbase, int *N)
       fn = fp->next;
       i = sprintf(ln, "make %cscaltest urout=%s opt=\"", pre, fp->rout);
       if (fp->incX == 0) i += sprintf(ln+i, " -X 4 1 -1 2 -3");
-      if (pre == 'c' && pre == 'z') /* complex alphas */
+      if (pre == 'c' || pre == 'z') /* complex alphas */
       {
          if (fp->alpha == 0) /* imag = 0 */
             i += sprintf(ln+i, " -a 3 1.0 0.0 -1.0 0.0 0.9 0.0");
